#ifndef K3B_I18N_H
#define K3B_I18N_H

#define TRANSLATION_DOMAIN "libk3b"
#include <KLocalizedString>

#endif // K3B_I18N_H
